<?php

namespace ByDedi\MailBundle\Admin;

use ByDedi\AdminBundle\Admin\BaseAdmin;
use ByDedi\AdminBundle\Form\Type\CkeditorType;
use ByDedi\AdminBundle\Form\Type\CollectionType;
use ByDedi\AdminBundle\Form\Type\HistoryType;
use ByDedi\MailBundle\Entity\Mail;
use Sonata\AdminBundle\Datagrid\DatagridMapper;
use Sonata\AdminBundle\Datagrid\ListMapper;
use Sonata\AdminBundle\Form\FormMapper;
use Sonata\AdminBundle\Show\ShowMapper;
use Symfony\Component\Form\Extension\Core\Type\TextType;

class MailAdmin extends BaseAdmin
{
    protected $datagridValues = array(
        '_page' => 1,
        '_sort_order' => 'ASC',
        '_sort_by' => 'id'
    );

    /**
     * {@inheritdoc}
     */
    protected function configureListFields(ListMapper $listMapper)
    {
        $listMapper
            ->addIdentifier('id', null, ['label' => 'ID'])
            ->addIdentifier('name', null, ['label' => 'Libellé'])
            ->addIdentifier('status', null, ['label' => 'Statut']);

        $listMapper
            ->add('_action', 'actions', $this->getDefaultListActionParams());
    }


    /**
     * {@inheritdoc}
     */
    protected function configureDatagridFilters(DatagridMapper $datagridMapper)
    {
        $datagridMapper
            ->add('id')
            ->add('translations.name')
            ->add('status', 'doctrine_orm_string', ['label' => 'Statut'], 'choice', ['choices' => ['Inactif' => '0', 'Actif' => '1']]);
    }


    /**
     * {@inheritdoc}
     */
    protected function configureFormFields(FormMapper $formMapper)
    {
        $mail = $this->getSubject();
        $isUpdate = (bool)($mail instanceof Mail && $mail->getId());

        $env = $this->container->get('kernel')->getEnvironment();
        $formMapper
            ->tab('Informations principales')
            ->with('Identification', [])
            ->add(
                'translations',
                'A2lix\TranslationFormBundle\Form\Type\TranslationsType',
                $this->setTranslatableFieldsOptions([
                    'name' => [
                        'field_type' => 'text',
                        'label' => 'Nom',
                    ]
                ])
            )
            ->add(
                'code',
                TextType::class,
                [
                    'label' => 'Code',
                    'attr' => [
                        'readonly' => $env != 'dev',
                        'required' => $env != 'dev',
                    ],
                ]
            )
            ->add('status', 'choice', [
                'label' => 'Statut',
                'choices' => [
                    'Inactif' => false,
                    'Actif' => true
                ]
            ])
            ->end()
            ->with('Corps du mail', [])
            ->add(
                'translations1',
                'A2lix\TranslationFormBundle\Form\Type\TranslationsType',
                $this->setTranslatableFieldsOptions([
                    'object' => [
                        'field_type' => 'text',
                        'label' => 'Objet',
                    ],
                    /* 'text' => [
                         'label' => 'Texte',
                     ],*/
                    'html' => [
                        'field_type' => CkeditorType::class,
                        'label' => 'HTML',
                    ],
                ])
            )
            ->end()
            ->end();
    }


    /**
     * {@inheritdoc}
     */
    public function toString($object)
    {
        return $object instanceof Mail
            ? $object->getName() . ' #' . $object->getId()
            : "Mail"; // shown in the breadcrumb on the create view
    }
}
