<?php
/**
 * Created by PhpStorm.
 * User: FrédéricGuichard
 * Date: 05/04/2017
 * Time: 17:03
 */

namespace ByDedi\MailBundle\Helper;

use ByDedi\CoreBundle\Mailer\MailSender;
use ByDedi\CoreBundle\Utils\FileSystemManager;
use ByDedi\CoreBundle\Utils\StringModifier;
use ByDedi\MailBundle\Entity\Mail;
use Doctrine\Common\Persistence\ObjectManager;
use Doctrine\ORM\EntityNotFoundException;

class MailSenderHelper
{
    private $mailSender;
    private $manager;
    private $fileSystemManager;

    public function __construct(MailSender $mailSender, ObjectManager $manager, FileSystemManager $fileSystemManager)
    {
        $this->mailSender = $mailSender;
        $this->manager = $manager;
        $this->fileSystemManager = $fileSystemManager;
    }

    public function getMailSender()
    {
        return $this->mailSender;
    }

    public function sendFromMailCode($code, $to = [], $from = [], $tags = array(), $files = array(), $template = 'MailBundle:Email:default.html.twig')
    {
        $mail = $this->manager->getRepository(Mail::class)->findOneBy(['code' => $code]);

        if (!$mail instanceof Mail) {
            throw new EntityNotFoundException(sprintf('mail code %s not found', $code));
        }

        if (!empty($files)) {
            foreach ($files as $file) {
                if (file_exists($this->fileSystemManager->getWebDir().$file['path'])) {
                    $this->mailSender->addAttachment(
                        $file['name'],
                        $this->fileSystemManager->getWebDir() . $file['path']
                    );
                }
            }
        }

        if (!empty($to)) {
            $this->mailSender->setTo($to);
        }

        if (!empty($from)) {
            $this->mailSender->setFrom($from);
        }

        $this->mailSender->setSubject(StringModifier::replaceTags($mail->getObject(), $tags));
        $this->mailSender->setBody(StringModifier::replaceTags($mail->getHtml(), $tags));

        $this->mailSender->setTemplate($template);

        return $this->mailSender->send();
    }
}
